@@ -76,12 +76,9 @@
 	     (set! lines (cons (and (pair? (car x)) (pair-line-number (car x))) lines))
 	     (set! files (cons (and (pair? (car x)) (pair-filename (car x))) files)))))
 
-       ;; show the enclosing contexts
-       (let ((old-print-length (*s7* 'print-length)))
-	 (set! (*s7* 'print-length) 8)
+       (let-temporarily (((*s7* 'print-length) 8))
 	 (do ((e (outlet ow) (outlet e)))
-	     ((memq e elist)
-	      (set! (*s7* 'print-length) old-print-length))
+	     ((memq e elist))
 	   (if (and (number? (length e)) ; with-let + mock-data + length method?
 		    (> (length e) 0))
 	       (format p "~%~{~A~| ~}~%" e)
@@ -198,7 +195,7 @@
 	(lambda args #f)))))
 
 (define linearize
-  (let ((+documentation+ " (linearize lst) turns a circular list into normal list:\n\
+  (let ((+documentation+ "(linearize lst) turns a circular list into normal list:\n\
     (linearize (circular-list 1 2)) -> '(1 2)"))
     (lambda (lst)
       (let lin-1 ((lst lst)
@@ -1277,7 +1274,6 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 |#
 ;; ideally this would simply vanish, and make no change in the run-time state, but (values) here returns #<unspecified>
 ;;   (let ((a 1) (b 2)) (list (set! a 3) (reflective-probe) b)) -> '(3 2) not '(3 #<unspecified> 2)
-;;   I was too timid when I started s7 and thought (then) that (abs -1 (values)) should be an error
 ;; perhaps if we want it to disappear:
 
 (define-bacro (reflective-probe . body)
@@ -1471,7 +1467,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
   (if (not (string? name))
       (error 'wrong-type-arg "directory name should be a string: ~S" name)
       (make-iterator
-       (with-let (sublet *libc* :name name :recursive recursive)
+       (with-let (sublet *libc* :name name :recursive recursive :NULL (c-pointer 0 'void*))
 	 (let ((dir (opendir name)))
 	   (if (equal? dir NULL)
 	       (error 'io-error "can't open ~S: ~S" name (strerror (errno)))
